@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Ported Perl from the book's C code
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0301';
 
 use Moo;
 use strictures 2;
@@ -503,7 +503,7 @@ Music::CreatingRhythms - Ported Perl from the book's C code
 
 =head1 VERSION
 
-version 0.0300
+version 0.0301
 
 =head1 SYNOPSIS
 
@@ -545,13 +545,26 @@ Create a new C<Music::CreatingRhythms> object.
 
 Calculate a continued fraction convergent given the B<terms>.
 
+Examples:
+
+  $got = $mcr->cfcv(1, 2);       # [3,2]
+  $got = $mcr->cfcv(1, 2, 2);    # [7,5]
+  $got = $mcr->cfcv(1, 2, 2, 2); # [17,12]
+
 =head2 cfsqrt
 
+  $terms = $mcr->cfsqrt($n);
   $terms = $mcr->cfsqrt($n, $m);
 
 Calculate the continued fraction for C<sqrt(n)> to B<m> digits, where
 B<n> and B<m> are integers.
 
+Examples:
+
+  $got = $mcr->cfsqrt(2, 2); # [1,2]
+  $got = $mcr->cfsqrt(2, 3); # [1,2,2]
+  $got = $mcr->cfsqrt(2, 4); # [1,2,2,2]
+
 =head2 chsequl
 
   $sequence = $mcr->chsequl($t, $p, $q);
@@ -561,10 +574,10 @@ Generate the upper or lower Christoffel word for B<p> and B<q>.
 
 Arguments:
 
-  $t: required type of word (u: upper, l: lower)
-  $p: required numerator of slope
-  $q: required denominator of slope
-  $n: optional number of terms to generate, default: p+q
+  t: required type of word (u: upper, l: lower)
+  p: required numerator of slope
+  q: required denominator of slope
+  n: optional number of terms to generate, default: p+q
 
 =head2 comp
 
@@ -572,6 +585,14 @@ Arguments:
 
 Generate all compositions of B<n>.
 
+A "composition" is the set of combinatorial "variations" of the
+partitions of B<n> with the duplicates removed.
+
+Example:
+
+  $got = $mcr->comp(4);
+  # [1,1,1,1],[1,1,2],[1,2,1],[1,3],[2,1,1],[2,2],[3,1],[4]
+
 =head2 compa
 
   $compositions = $mcr->compa($n, @intervals);
@@ -579,6 +600,13 @@ Generate all compositions of B<n>.
 Generate compositions of B<n> with allowed intervals
 B<p1, p2, ... pn>.
 
+Here, the "intervals" are the terms of the partition.
+
+Example:
+
+  $got = $mcr->compa(4, 1,2);
+  # [[1,1,1,1],[1,1,2],[1,2,1],[2,1,1],[2,2]]
+
 =head2 compam
 
   $compositions = $mcr->compam($n, $m, @intervals);
@@ -586,18 +614,34 @@ B<p1, p2, ... pn>.
 Generate compositions of B<n> with B<m> parts and allowed intervals
 B<p1, p2, ... pn>.
 
+Here, the "parts" are the number of elements of each interval set.
+
+Example:
+
+  $got = $mcr->compam(4, 3, 1,2); # [[1,1,2],[1,2,1],[2,1,1]]
+
 =head2 compm
 
   $compositions = $mcr->compm($n, $m);
 
 Generate all compositions of B<n> into B<m> parts.
 
+Again, the "parts" are the number of elements of each interval set.
+
+Example:
+
+  $got = $mcr->compm(4, 2); # [[1,3],[2,2],[3,1]]
+
 =head2 debruijn_n
 
   $sequence = $mcr->debruijn_n($n);
 
 Generate the largest de Bruijn sequence of order B<n>.
 
+Example:
+
+  $got = $mcr->debruijn_n(3); # 1 1 1 0 1 0 0 0
+
 =head2 euclid
 
   $sequence = $mcr->euclid($n, $m);
@@ -605,24 +649,49 @@ Generate the largest de Bruijn sequence of order B<n>.
 Generate a Euclidean rhythm given B<n> onsets distributed over B<m>
 beats.
 
+Examples:
+
+  $got = $mcr->euclid(1, 4); # [1,0,0,0]
+  $got = $mcr->euclid(2, 4); # [1,0,1,0]
+  $got = $mcr->euclid(3, 4); # [1,1,0,1]
+  $got = $mcr->euclid(4, 4); # [1,1,1,1]
+
 =head2 invert_at
 
   $sequence = $mcr->invert_at($n, $parts);
 
 Invert a section of a B<parts> binary sequence at B<n>.
 
+Examples:
+
+    $parts = [qw(1 0 1 0 0)];
+    $got = $mcr->invert_at(0, $parts); # 0 1 0 1 1
+    $got = $mcr->invert_at(1, $parts); # 1 1 0 1 1
+    $got = $mcr->invert_at(2, $parts); # 1 0 0 1 1
+
 =head2 neck
 
   $necklaces = $mcr->neck($n);
 
 Generate all binary necklaces of length B<n>.
 
+Example:
+
+  $got = $mcr->neck(3); # [1,1,1],[1,1,0],[1,0,0],[0,0,0]
+
 =head2 necka
 
   $necklaces = $mcr->necka($n, @intervals);
 
 Generate binary necklaces of length B<n> with allowed intervals
-B<p1, p2, ... pn>.
+B<p1, p2, ... pn>. For these "necklace" class of functions, the word
+"intervals" refers to the size of a number given trailing zeros. So
+intervals C<1>, C<2>, and C<3> are represented as C<1>, C<1,0>, and
+C<1,0,0> respectively.
+
+Example:
+
+  $got = $mcr->necka(4, 1,2); # [1,1,1,1],[1,1,1,0],[1,0,1,0]
 
 =head2 neckam
 
@@ -631,18 +700,30 @@ B<p1, p2, ... pn>.
 Generate binary necklaces of length B<n> with B<m> ones, and allowed
 intervals B<p1, p2, ... pn>.
 
+Example:
+
+  $got = $mcr->neckam(4, 3, 1,2); # [[1,1,1,0]]
+
 =head2 neckm
 
   $necklaces = $mcr->neckm($n, $m);
 
 Generate all binary necklaces of length B<n> with B<m> ones.
 
+Example:
+
+  $got = $mcr->neckm(4, 2); # [[1,1,0,0],[1,0,1,0]]
+
 =head2 part
 
   $partitions = $mcr->part($n);
 
 Generate all partitions of B<n>.
 
+Example:
+
+  $got = $mcr->part(4); # [1,1,1,1],[1,1,2],[2,2],[1,3],[4]
+
 =head2 parta
 
   $partitions = $mcr->parta($n, @intervals);
@@ -650,6 +731,10 @@ Generate all partitions of B<n>.
 Generate all partitions of B<n> with allowed intervals
 B<p1, p2, ... pn>.
 
+Example:
+
+    $got = $mcr->parta(4, 1,2); # [1,1,1,1],[1,1,2],[2,2]
+
 =head2 partam
 
   $partitions = $mcr->partam($n, $m, @intervals);
@@ -657,15 +742,23 @@ B<p1, p2, ... pn>.
 Generate all partitions of B<n> with B<m> parts from the intervals
 B<p1, p2, ... pn>.
 
+Example:
+
+  $got = $mcr->partam(4, 2, 2); # [2,2]
+
 =head2 partm
 
   $partitions = $mcr->partm($n, $m);
 
 Generate all partitions of B<n> into B<m> parts.
 
+Example:
+
+  $got = $mcr->partm(4, 2); # [1,3],[2,2]
+
 =head2 permi
 
-  $all_permutations = $mcr->permi(\@parts);
+  $permutations = $mcr->permi(\@parts);
 
 Return all permutations of the given B<parts> list as an
 array-reference of array-references.
@@ -673,11 +766,40 @@ array-reference of array-references.
 (For an efficient iterator, check out the L<Algorithm::Combinatorics>
 module.)
 
+Example:
+
+  my $parts = [qw(1 0 1)];
+  my $got = $mcr->permi($parts);
+  # [1,0,1],[1,1,0],[0,1,1],[0,1,1],[1,1,0],[1,0,1]
+
 =head2 pfold
 
   $sequences = $mcr->pfold($n, $m, $f);
 
-Generate fold sequences.
+Generate "paper folding" sequences, where B<n> is the number of terms
+to calculate, B<m> is the size of the binary representation of the
+folding function, and B<f> is the folding function number, which can
+range from C<0> to C<2^m - 1>.
+
+To quote the book, "Put a rectangular strip of paper on a flat surface
+in front of you, with the long dimension going left to right. Now pick
+up the right end of the paper and fold it over onto the left end.
+Repeat this process a few times and unfold the paper. [There will be]
+a sequence of creases in the paper, some will look like valleys and
+some will look like ridges... Let valley creases be symbolized by the
+number 1 and ridge creases by the number 0..."
+
+Example:
+
+  # "regular paper folding sequence"
+  # "folding in the same direction all the time"
+  $got = $mcr->pfold(1, 1, 1); # [1]
+  $got = $mcr->pfold(2, 1, 1); # [1,1]
+  $got = $mcr->pfold(3, 1, 1); # [1,1,0]
+
+  # but other parameters can generate more interesting rhythms...
+  $got = $mcr->pfold(15, 4, 0); # [0,0,1,0,0,1,1,0,0,0,1,1,0,1,1]
+  $got = $mcr->pfold(15, 4, 1); # [1,0,0,0,1,1,0,0,1,0,0,1,1,1,0]
 
 =head2 reverse_at
 
@@ -685,12 +807,30 @@ Generate fold sequences.
 
 Reverse a section of a B<parts> sequence at B<n>.
 
+Examples:
+
+  $parts = [qw(1 0 1 0 0)];
+  $got = $mcr->reverse_at(0, $parts); # 0 0 1 0 1
+  $got = $mcr->reverse_at(1, $parts); # 1 0 0 1 0
+  $got = $mcr->reverse_at(2, $parts); # 1 0 0 0 1
+  $got = $mcr->reverse_at(3, $parts); # 1 0 1 0 0
+
 =head2 rotate_n
 
   $sequence = $mcr->rotate_n($n, $parts);
 
 Rotate a necklace of the given B<parts>, B<n> times.
 
+Examples:
+
+  $parts = [qw(1 0 1 0 0)];
+  $got = $mcr->rotate_n(0, $parts); # 1 0 1 0 0
+  $got = $mcr->rotate_n(1, $parts); # 0 1 0 1 0
+  $got = $mcr->rotate_n(2, $parts); # 0 0 1 0 1
+  $got = $mcr->rotate_n(3, $parts); # 1 0 0 1 0
+  $got = $mcr->rotate_n(4, $parts); # 0 1 0 0 1
+  $got = $mcr->rotate_n(5, $parts); # 1 0 1 0 0
+
 =head1 SEE ALSO
 
 L<https://abrazol.com/books/rhythm1/> "Creating Rhythms"
